@@ -989,18 +989,19 @@ variable to point to an accessible directory.
         extract, as it tracks the generated names for possible cleanup later.
         """
         extract_path = self.extraction_path or get_default_cache()
-        self._warn_unsafe_extraction_path(extract_path)
         target_path = os.path.join(extract_path, archive_name+'-tmp', *names)
         try:
             _bypass_ensure_directory(target_path)
         except:
             self.extraction_error()
 
+        self._warn_unsafe_extraction_path(extract_path)
+
         self.cached_files[target_path] = 1
         return target_path
 
     @staticmethod
-    def warn_unsafe_extraction_path(path):
+    def _warn_unsafe_extraction_path(path):
         """
         If the default extraction path is overridden and set to an insecure
         location, such as /tmp, it opens up an opportunity for an attacker to
